/*
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * (the "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at <http://www.mozilla.org/MPL/>.
 * 
 * Software distributed under the License is distributed on an "AS IS" basis, WITHOUT
 * WARRANTY OF ANY KIND, either express or implied. See the License for the specific
 * language governing rights and limitations under the License.
 * 
 * The Original Code is the Venice Web Communities System.
 * 
 * The Initial Developer of the Original Code is Eric J. Bowersox <erbo@silcom.com>,
 * for Silverwrist Design Studios.  Portions created by Eric J. Bowersox are
 * Copyright (C) 2003 Eric J. Bowersox/Silverwrist Design Studios.  All Rights Reserved.
 * 
 * Contributor(s): 
 */
package com.silverwrist.venice.conf.impl;

import java.util.*;
import com.silverwrist.dynamo.db.OpsBase;
import com.silverwrist.dynamo.except.*;
import com.silverwrist.dynamo.iface.*;

abstract class ConferenceManagerOps extends OpsBase
{
  /*--------------------------------------------------------------------------------
   * Static data members
   *--------------------------------------------------------------------------------
   */

  static final String KEY_CONFID = "confid";
  static final String KEY_CREATE_DATE = "createdate";
  static final String KEY_LAST_UPDATE = "lastupdate";
  static final String KEY_HOSTS_GID = "hosts_gid";
  static final String KEY_ACLID = "aclid";
  static final String KEY_NAME = "name";
  static final String KEY_SEQUENCE = "sequence";
  static final String KEY_HIDE = "hide";

  /*--------------------------------------------------------------------------------
   * Attributes
   *--------------------------------------------------------------------------------
   */

  private ConferenceOps m_confops = null;
  private LinkedConferenceOps m_linkedops = null;

  /*--------------------------------------------------------------------------------
   * Constructor
   *--------------------------------------------------------------------------------
   */

  protected ConferenceManagerOps(DBConnectionPool pool)
  {
    super(pool);

  } // end constructor

  /*--------------------------------------------------------------------------------
   * Overrides from class OpsBase
   *--------------------------------------------------------------------------------
   */

  public void dispose()
  {
    if (m_confops!=null)
      m_confops.dispose();
    m_confops = null;
    if (m_linkedops!=null)
      m_linkedops.dispose();
    m_linkedops = null;
    super.dispose();

  } // end dispose

  /*--------------------------------------------------------------------------------
   * Abstract operations
   *--------------------------------------------------------------------------------
   */

  protected abstract ConferenceOps createConferenceOps(DBConnectionPool pool);

  protected abstract LinkedConferenceOps createLinkedConferenceOps(DBConnectionPool pool);

  abstract List getConferences(int cid) throws DatabaseException;

  abstract Map getConferenceData(int confid) throws DatabaseException;

  abstract Map getConferenceData(int cid, int confid) throws DatabaseException;

  abstract Map getConferenceData(String alias) throws DatabaseException;

  abstract Map getConferenceData(int cid, String alias) throws DatabaseException;

  /*--------------------------------------------------------------------------------
   * External operations
   *--------------------------------------------------------------------------------
   */

  synchronized ConferenceOps getConferenceOps()
  {
    if (m_confops==null)
      m_confops = createConferenceOps(getPool());
    return m_confops;

  } // end getConferenceOps

  synchronized LinkedConferenceOps getLinkedConferenceOps()
  {
    if (m_linkedops==null)
      m_linkedops = createLinkedConferenceOps(getPool());
    return m_linkedops;

  } // end getConferenceOps

  /*--------------------------------------------------------------------------------
   * External static operations
   *--------------------------------------------------------------------------------
   */

  static ConferenceManagerOps get(DBConnectionPool pool) throws ConfigException
  {
    return (ConferenceManagerOps)get(pool,ConferenceManagerOps.class.getClassLoader(),
				     ConferenceManagerOps.class.getName() + "_","ConferenceManagerOps");

  } // end get

} // end class ConferenceManagerOps
