/*
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * (the "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at <http://www.mozilla.org/MPL/>.
 * 
 * Software distributed under the License is distributed on an "AS IS" basis, WITHOUT
 * WARRANTY OF ANY KIND, either express or implied. See the License for the specific
 * language governing rights and limitations under the License.
 * 
 * The Original Code is the Venice Web Communities System.
 * 
 * The Initial Developer of the Original Code is Eric J. Bowersox <erbo@silcom.com>,
 * for Silverwrist Design Studios.  Portions created by Eric J. Bowersox are
 * Copyright (C) 2003 Eric J. Bowersox/Silverwrist Design Studios.  All Rights Reserved.
 * 
 * Contributor(s): 
 */
package com.silverwrist.venice.conf.impl;

import java.sql.*;
import java.util.*;
import com.silverwrist.util.*;
import com.silverwrist.dynamo.except.*;
import com.silverwrist.dynamo.iface.*;
import com.silverwrist.dynamo.util.*;

public class ConferenceManagerOps_mysql extends ConferenceManagerOps
{
  /*--------------------------------------------------------------------------------
   * Attributes
   *--------------------------------------------------------------------------------
   */

  private DBUtilities m_utils;

  /*--------------------------------------------------------------------------------
   * Constructor
   *--------------------------------------------------------------------------------
   */

  public ConferenceManagerOps_mysql(DBConnectionPool pool)
  {
    super(pool);
    m_utils = (DBUtilities)(pool.queryService(DBUtilities.class));

  } // end constructor

  /*--------------------------------------------------------------------------------
   * Overrides from class ConferenceManagerOps
   *--------------------------------------------------------------------------------
   */

  public void dispose()
  {
    m_utils = null;
    super.dispose();

  } // end dispose

  /*--------------------------------------------------------------------------------
   * Abstract implementations from class ConferenceManagerOps
   *--------------------------------------------------------------------------------
   */

  protected ConferenceOps createConferenceOps(DBConnectionPool pool)
  {
    return new ConferenceOps_mysql(pool);

  } // end createConferenceOps

  protected LinkedConferenceOps createLinkedConferenceOps(DBConnectionPool pool)
  {
    return new LinkedConferenceOps_mysql(pool);

  } // end createLinkedConferenceOps

  List getConferences(int cid) throws DatabaseException
  {
    Connection conn = null;
    PreparedStatement stmt = null;
    ResultSet rs = null;
    try
    { // get a connection
      conn = getConnection();

      // create and execute the statement
      stmt = conn.prepareStatement("SELECT c.confid, c.createdate, c.lastupdate, c.hosts_gid, c.aclid, c.name, "
				   + "l.sequence, l.hide FROM conferences c, conf_links l WHERE c.confid = l.confid "
				   + "AND l.cid = ? ORDER by l.sequence;");
      stmt.setInt(1,cid);
      rs = stmt.executeQuery();

      // prepare the return value (a list of maps)
      ArrayList rc = new ArrayList();
      while (rs.next())
      { // load the fields into the HashMaps
	HashMap tmp = new HashMap();
	tmp.put(KEY_CONFID,new Integer(rs.getInt(1)));
	tmp.put(KEY_CREATE_DATE,m_utils.getDateTime(rs,2));
	java.util.Date d = m_utils.getDateTime(rs,3);
	if (d!=null)
	  tmp.put(KEY_LAST_UPDATE,d);
	tmp.put(KEY_HOSTS_GID,new Integer(rs.getInt(4)));
	tmp.put(KEY_ACLID,new Integer(rs.getInt(5)));
	tmp.put(KEY_NAME,rs.getString(6));
	tmp.put(KEY_SEQUENCE,new Integer(rs.getInt(7)));
	tmp.put(KEY_HIDE,(rs.getInt(8)==1) ? Boolean.TRUE : Boolean.FALSE);
	rc.add(tmp);

      } // end while

      return rc;

    } // end try
    catch (SQLException e)
    { // translate to a general DatabaseException
      throw generalException(e);

    } // end catch
    finally
    { // shut everything down
      SQLUtils.shutdown(rs);
      SQLUtils.shutdown(stmt);
      SQLUtils.shutdown(conn);

    } // end finally

  } // end getConferences

  Map getConferenceData(int confid) throws DatabaseException
  {
    Connection conn = null;
    PreparedStatement stmt = null;
    ResultSet rs = null;
    try
    { // get a connection
      conn = getConnection();

      // create and execute the statement
      stmt = conn.prepareStatement("SELECT createdate, lastupdate, hosts_gid, aclid, name FROM conferences "
				   + "WHERE confid = ?");
      stmt.setInt(1,confid);
      rs = stmt.executeQuery();
      if (!(rs.next()))
	return null;

      // prepare the return value
      HashMap rc = new HashMap();
      rc.put(KEY_CONFID,new Integer(confid));
      rc.put(KEY_CREATE_DATE,m_utils.getDateTime(rs,1));
      java.util.Date d = m_utils.getDateTime(rs,2);
      if (d!=null)
	rc.put(KEY_LAST_UPDATE,d);
      rc.put(KEY_HOSTS_GID,new Integer(rs.getInt(3)));
      rc.put(KEY_ACLID,new Integer(rs.getInt(4)));
      rc.put(KEY_NAME,rs.getString(5));
      return rc;

    } // end try
    catch (SQLException e)
    { // translate to a general DatabaseException
      throw generalException(e);

    } // end catch
    finally
    { // shut everything down
      SQLUtils.shutdown(rs);
      SQLUtils.shutdown(stmt);
      SQLUtils.shutdown(conn);

    } // end finally

  } // end getConferenceData

  Map getConferenceData(int cid, int confid) throws DatabaseException
  {
    Connection conn = null;
    PreparedStatement stmt = null;
    ResultSet rs = null;
    try
    { // get a connection
      conn = getConnection();

      // create and execute the statement
      stmt = conn.prepareStatement("SELECT c.createdate, c.lastupdate, c.hosts_gid, c.aclid, c.name, l.sequence, "
				   + "l.hide FROM conferences c, conf_links l WHERE c.confid = ? "
				   + "AND c.confid = l.confid AND l.cid = ?");
      stmt.setInt(1,confid);
      stmt.setInt(2,cid);
      rs = stmt.executeQuery();
      if (!(rs.next()))
	return null;

      // prepare the return value
      HashMap rc = new HashMap();
      rc.put(KEY_CONFID,new Integer(confid));
      rc.put(KEY_CREATE_DATE,m_utils.getDateTime(rs,1));
      java.util.Date d = m_utils.getDateTime(rs,2);
      if (d!=null)
	rc.put(KEY_LAST_UPDATE,d);
      rc.put(KEY_HOSTS_GID,new Integer(rs.getInt(3)));
      rc.put(KEY_ACLID,new Integer(rs.getInt(4)));
      rc.put(KEY_NAME,rs.getString(5));
      rc.put(KEY_SEQUENCE,new Integer(rs.getInt(6)));
      rc.put(KEY_HIDE,(rs.getInt(7)==1) ? Boolean.TRUE : Boolean.FALSE);
      return rc;

    } // end try
    catch (SQLException e)
    { // translate to a general DatabaseException
      throw generalException(e);

    } // end catch
    finally
    { // shut everything down
      SQLUtils.shutdown(rs);
      SQLUtils.shutdown(stmt);
      SQLUtils.shutdown(conn);

    } // end finally

  } // end getConferenceData

  Map getConferenceData(String alias) throws DatabaseException
  {
    Connection conn = null;
    PreparedStatement stmt = null;
    ResultSet rs = null;
    try
    { // get a connection
      conn = getConnection();

      // create and execute the statement
      stmt = conn.prepareStatement("SELECT c.confid, c.createdate, c.lastupdate, c.hosts_gid, c.aclid, c.name "
				   + "FROM conferences c, conf_alias a WHERE c.confid = a.confid AND a.alias = ?;");
      stmt.setString(1,alias);
      rs = stmt.executeQuery();
      if (!(rs.next()))
	return null;

      // prepare the return value
      HashMap rc = new HashMap();
      rc.put(KEY_CONFID,new Integer(rs.getInt(1)));
      rc.put(KEY_CREATE_DATE,m_utils.getDateTime(rs,2));
      java.util.Date d = m_utils.getDateTime(rs,3);
      if (d!=null)
	rc.put(KEY_LAST_UPDATE,d);
      rc.put(KEY_HOSTS_GID,new Integer(rs.getInt(4)));
      rc.put(KEY_ACLID,new Integer(rs.getInt(5)));
      rc.put(KEY_NAME,rs.getString(6));
      return rc;

    } // end try
    catch (SQLException e)
    { // translate to a general DatabaseException
      throw generalException(e);

    } // end catch
    finally
    { // shut everything down
      SQLUtils.shutdown(rs);
      SQLUtils.shutdown(stmt);
      SQLUtils.shutdown(conn);

    } // end finally

  } // end getConferenceData

  Map getConferenceData(int cid, String alias) throws DatabaseException
  {
    Connection conn = null;
    PreparedStatement stmt = null;
    ResultSet rs = null;
    try
    { // get a connection
      conn = getConnection();

      // create and execute the statement
      stmt = conn.prepareStatement("SELECT c.confid, c.createdate, c.lastupdate, c.hosts_gid, c.aclid, c.name, "
				   + "l.sequence, l.hide FROM conferences c, conf_alias a, conf_links l "
				   + "WHERE c.confid = a.confid AND a.alias = ? AND c.confid = l.confid "
				   + "AND l.cid = ?;");
      stmt.setString(1,alias);
      stmt.setInt(2,cid);
      rs = stmt.executeQuery();
      if (!(rs.next()))
	return null;

      // prepare the return value
      HashMap rc = new HashMap();
      rc.put(KEY_CONFID,new Integer(rs.getInt(1)));
      rc.put(KEY_CREATE_DATE,m_utils.getDateTime(rs,2));
      java.util.Date d = m_utils.getDateTime(rs,3);
      if (d!=null)
	rc.put(KEY_LAST_UPDATE,d);
      rc.put(KEY_HOSTS_GID,new Integer(rs.getInt(4)));
      rc.put(KEY_ACLID,new Integer(rs.getInt(5)));
      rc.put(KEY_NAME,rs.getString(6));
      rc.put(KEY_SEQUENCE,new Integer(rs.getInt(7)));
      rc.put(KEY_HIDE,(rs.getInt(8)==1) ? Boolean.TRUE : Boolean.FALSE);
      return rc;

    } // end try
    catch (SQLException e)
    { // translate to a general DatabaseException
      throw generalException(e);

    } // end catch
    finally
    { // shut everything down
      SQLUtils.shutdown(rs);
      SQLUtils.shutdown(stmt);
      SQLUtils.shutdown(conn);

    } // end finally

  } // end getConferenceData

} // end class ConferenceManagerOps_mysql
