/*
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * (the "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at <http://www.mozilla.org/MPL/>.
 * 
 * Software distributed under the License is distributed on an "AS IS" basis, WITHOUT
 * WARRANTY OF ANY KIND, either express or implied. See the License for the specific
 * language governing rights and limitations under the License.
 * 
 * The Original Code is the Venice Web Communities System.
 * 
 * The Initial Developer of the Original Code is Eric J. Bowersox <erbo@silcom.com>,
 * for Silverwrist Design Studios.  Portions created by Eric J. Bowersox are
 * Copyright (C) 2003 Eric J. Bowersox/Silverwrist Design Studios.  All Rights Reserved.
 * 
 * Contributor(s): 
 */
package com.silverwrist.venice.conf.obj;

import java.security.acl.*;
import java.util.*;
import com.silverwrist.dynamo.except.*;
import com.silverwrist.dynamo.iface.*;
import com.silverwrist.dynamo.obj.*;
import com.silverwrist.venice.iface.*;
import com.silverwrist.venice.conf.iface.*;

public class DynamicImplLinkedConference extends DynamicImplConference
{
  /*--------------------------------------------------------------------------------
   * Static data members
   *--------------------------------------------------------------------------------
   */

  private static DynamicClass s_baseclass = null;

  /*--------------------------------------------------------------------------------
   * Attributes
   *--------------------------------------------------------------------------------
   */

  private VeniceLinkedConference m_impl;

  /*--------------------------------------------------------------------------------
   * Constructors
   *--------------------------------------------------------------------------------
   */

  public DynamicImplLinkedConference(VeniceLinkedConference impl, DynamicClass dclass)
  {
    super(impl,dclass);
    m_impl = impl;

  } // end constructor

  public DynamicImplLinkedConference(VeniceLinkedConference impl)
  {
    super(impl,getBaseDClass());
    m_impl = impl;

  } // end constructor

  /*--------------------------------------------------------------------------------
   * Overrides from class DynamicObjectImpl
   *--------------------------------------------------------------------------------
   */

  public Object get(String property_name) throws DynamicObjectException
  {
    if (property_name.equals("community"))
      return m_impl.getCommunity();
    if (property_name.equals("conference"))
      return m_impl.getConference();
    if (property_name.equals("sequence"))
      return new Integer(m_impl.getSequence());
    if (property_name.equals("hidden"))
      return Boolean.valueOf(m_impl.isHidden());
    return super.get(property_name);

  } // end get

  public Object call(String method_name, Object[] parameters) throws DynamicObjectException
  {
    if (method_name.equals("getCommunity"))
    { // verify parameters and call method
      verifyParameterLength(method_name,parameters,0);
      return m_impl.getCommunity();

    } // end if

    if (method_name.equals("getConference"))
    { // verify parameters and call method
      verifyParameterLength(method_name,parameters,0);
      return m_impl.getConference();

    } // end if

    if (method_name.equals("getSequence"))
    { // verify parameters and call method
      verifyParameterLength(method_name,parameters,0);
      return new Integer(m_impl.getSequence());

    } // end if

    if (method_name.equals("setSequence"))
    { // verify parameters and call method
      try
      { // make sure and catch exceptions
	verifyParameterLength(method_name,parameters,2);
	verifyParameterType(method_name,parameters,0,DynamoUser.class);
	int foo = getIntValue(method_name,parameters,1);
	m_impl.setSequence((DynamoUser)(parameters[0]),foo);
	return null;

      } // end try
      catch (DatabaseException e)
      { // catch and turn into a call failure
	throw callFailed(e);

      } // end catch
      catch (DynamoSecurityException e)
      { // catch and turn into a call failure
	throw callFailed(e);

      } // end catch

    } // end if

    if (method_name.equals("isHidden"))
    { // verify parameters and call method
      verifyParameterLength(method_name,parameters,0);
      return Boolean.valueOf(m_impl.isHidden());

    } // end if

    if (method_name.equals("setHidden"))
    { // verify parameters and call method
      try
      { // make sure and catch exceptions
	verifyParameterLength(method_name,parameters,2);
	verifyParameterType(method_name,parameters,0,DynamoUser.class);
	boolean foo = getBooleanValue(method_name,parameters,1);
	m_impl.setHidden((DynamoUser)(parameters[0]),foo);
	return null;

      } // end try
      catch (DatabaseException e)
      { // catch and turn into a call failure
	throw callFailed(e);

      } // end catch
      catch (DynamoSecurityException e)
      { // catch and turn into a call failure
	throw callFailed(e);

      } // end catch

    } // end if

    if (method_name.equals("unlink"))
    { // verify parameters and call method
      try
      { // make sure and catch exceptions
	verifyParameterLength(method_name,parameters,1);
	verifyParameterType(method_name,parameters,0,DynamoUser.class);
	m_impl.unlink((DynamoUser)(parameters[0]));
	return null;

      } // end try
      catch (DatabaseException e)
      { // catch and turn into a call failure
	throw callFailed(e);

      } // end catch
      catch (DynamoSecurityException e)
      { // catch and turn into a call failure
	throw callFailed(e);

      } // end catch

    } // end if

    return super.call(method_name,parameters);

  } // end call

  /*--------------------------------------------------------------------------------
   * External static operations
   *--------------------------------------------------------------------------------
   */

  public static synchronized DynamicClass getBaseDClass()
  {
    if (s_baseclass==null)
      s_baseclass = new DynamicClassLinkedConference();
    return s_baseclass;

  } // end getBaseDClass

} // end class DynamicImplLinkedConference
