/*
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * (the "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at <http://www.mozilla.org/MPL/>.
 * 
 * Software distributed under the License is distributed on an "AS IS" basis, WITHOUT
 * WARRANTY OF ANY KIND, either express or implied. See the License for the specific
 * language governing rights and limitations under the License.
 * 
 * The Original Code is the Venice Web Communities System.
 * 
 * The Initial Developer of the Original Code is Eric J. Bowersox <erbo@silcom.com>,
 * for Silverwrist Design Studios.  Portions created by Eric J. Bowersox are
 * Copyright (C) 2003 Eric J. Bowersox/Silverwrist Design Studios.  All Rights Reserved.
 * 
 * Contributor(s): 
 */
package com.silverwrist.dynamo.index;

import java.io.*;
import com.silverwrist.dynamo.db.OpsBase;
import com.silverwrist.dynamo.except.*;
import com.silverwrist.dynamo.iface.*;

abstract class IndexOps extends OpsBase
{
  /*--------------------------------------------------------------------------------
   * Constructor
   *--------------------------------------------------------------------------------
   */

  protected IndexOps(DBConnectionPool pool)
  {
    super(pool);

  } // end constructor

  /*--------------------------------------------------------------------------------
   * Abstract operations
   *--------------------------------------------------------------------------------
   */

  abstract String getAnalyzerClassName(int ndx) throws DatabaseException;

  abstract String[] listFiles(int ndx) throws DatabaseException;

  abstract long getModTime(int ndx, String file) throws DatabaseException;

  abstract void setModTime(int ndx, String file, long mtime) throws DatabaseException;

  abstract void deleteFile(int ndx, String file) throws DatabaseException;

  abstract void renameFile(int ndx, String oldfile, String newfile) throws DatabaseException;

  abstract int getLength(int ndx, String file) throws DatabaseException;

  abstract long createNewEntry(int ndx, String file) throws DatabaseException;

  abstract long loadFile(int ndx, String file, File output) throws DatabaseException, IOException;

  abstract void storeFile(int ndx, String file, long mtime, File input) throws DatabaseException, IOException;

  abstract boolean obtainLock(int ndx, String lock) throws DatabaseException;

  abstract void releaseLock(int ndx, String lock) throws DatabaseException;

  abstract boolean queryLock(int ndx, String lock) throws DatabaseException;

  abstract void releaseAllLocks(int ndx) throws DatabaseException;

} // end class IndexOps
