/*
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * (the "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at <http://www.mozilla.org/MPL/>.
 * 
 * Software distributed under the License is distributed on an "AS IS" basis, WITHOUT
 * WARRANTY OF ANY KIND, either express or implied. See the License for the specific
 * language governing rights and limitations under the License.
 * 
 * The Original Code is the Venice Web Communities System.
 * 
 * The Initial Developer of the Original Code is Eric J. Bowersox <erbo@silcom.com>,
 * for Silverwrist Design Studios.  Portions created by Eric J. Bowersox are
 * Copyright (C) 2003 Eric J. Bowersox/Silverwrist Design Studios.  All Rights Reserved.
 * 
 * Contributor(s): 
 */
package com.silverwrist.dynamo.obj;

import java.util.*;
import com.silverwrist.dynamo.except.*;
import com.silverwrist.dynamo.iface.*;

public class DynamicImplSecureObjectStore extends DynamicImplObjectProvider
{
  /*--------------------------------------------------------------------------------
   * Static data members
   *--------------------------------------------------------------------------------
   */

  private static DynamicClass s_baseclass = null;
  private static Set ALLOWED_METHODS;

  /*--------------------------------------------------------------------------------
   * Attributes
   *--------------------------------------------------------------------------------
   */

  private SecureObjectStore m_impl;

  /*--------------------------------------------------------------------------------
   * Constructors
   *--------------------------------------------------------------------------------
   */

  public DynamicImplSecureObjectStore(SecureObjectStore impl, DynamicClass dclass)
  {
    super(impl,dclass);
    m_impl = impl;

  } // end constructor

  public DynamicImplSecureObjectStore(SecureObjectStore impl)
  {
    super(impl,getBaseDClass());
    m_impl = impl;

  } // end constructor

  /*--------------------------------------------------------------------------------
   * Overrides from class DynamicImplObjectProvider
   *--------------------------------------------------------------------------------
   */

  public Object call(String method_name, Object[] parameters) throws DynamicObjectException
  {
    if (method_name.equals("setObject"))
    { // verify the parameters and call the method
      try
      { // make sure and capture known exceptions
	verifyParameterLength(method_name,parameters,4);
	verifyParameterType(method_name,parameters,0,DynamoUser.class);
	verifyParameterType(method_name,parameters,1,String.class);
	verifyParameterType(method_name,parameters,2,String.class);
	// N.B.: no need to verify parameter index 3
	return m_impl.setObject((DynamoUser)(parameters[0]),(String)(parameters[1]),(String)(parameters[2]),
				parameters[3]);

      } // end try
      catch (DatabaseException e)
      { // represents a call failure
	throw callFailed(e);

      } // end catch
      catch (DynamoSecurityException e)
      { // represents a call failure
	throw callFailed(e);

      } // end catch

    } // end if

    if (method_name.equals("removeObject"))
    { // verify the parameters and call the method
      try
      { // make sure and capture known exceptions
	verifyParameterLength(method_name,parameters,3);
	verifyParameterType(method_name,parameters,0,DynamoUser.class);
	verifyParameterType(method_name,parameters,1,String.class);
	verifyParameterType(method_name,parameters,2,String.class);
	return m_impl.removeObject((DynamoUser)(parameters[0]),(String)(parameters[1]),(String)(parameters[2]));

      } // end try
      catch (DatabaseException e)
      { // represents a call failure
	throw callFailed(e);

      } // end catch
      catch (DynamoSecurityException e)
      { // represents a call failure
	throw callFailed(e);

      } // end catch

    } // end if

    if (method_name.equals("getNamespaces"))
    { // verify the parameters and call the method
      try
      { // make sure and capture known exceptions
	verifyParameterLength(method_name,parameters,0);
	return m_impl.getNamespaces();

      } // end try
      catch (DatabaseException e)
      { // represents a call failure
	throw callFailed(e);

      } // end catch

    } // end if

    if (method_name.equals("getNamesForNamespace"))
    { // verify the parameters and call the method
      try
      { // make sure and capture known exceptions
	verifyParameterLength(method_name,parameters,1);
	verifyParameterType(method_name,parameters,0,String.class);
	return m_impl.getNamesForNamespace((String)(parameters[0]));

      } // end try
      catch (DatabaseException e)
      { // represents a call failure
	throw callFailed(e);

      } // end catch

    } // end if

    return super.call(method_name,parameters);

  } // end call

  public boolean canCall(String method_name)
  {
    if (ALLOWED_METHODS.contains(method_name))
      return true;
    else
      return super.canCall(method_name);

  } // end canCall

  /*--------------------------------------------------------------------------------
   * External static operations
   *--------------------------------------------------------------------------------
   */

  public static synchronized DynamicClass getBaseDClass()
  {
    if (s_baseclass==null)
      s_baseclass = new DynamicClassSecureObjectStore();
    return s_baseclass;

  } // end getBaseDClass

  /*--------------------------------------------------------------------------------
   * Static initializer
   *--------------------------------------------------------------------------------
   */

  static
  {
    HashSet tmp = new HashSet();
    tmp.add("setObject");
    tmp.add("removeObject");
    tmp.add("getNamespaces");
    tmp.add("getNamesForNamespace");
    ALLOWED_METHODS = Collections.unmodifiableSet(tmp);

  } // end static initializer

} // end class DynamicImplSecureObjectStore
