/*
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * (the "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at <http://www.mozilla.org/MPL/>.
 * 
 * Software distributed under the License is distributed on an "AS IS" basis, WITHOUT
 * WARRANTY OF ANY KIND, either express or implied. See the License for the specific
 * language governing rights and limitations under the License.
 * 
 * The Original Code is the Venice Web Communities System.
 * 
 * The Initial Developer of the Original Code is Eric J. Bowersox <erbo@silcom.com>,
 * for Silverwrist Design Studios.  Portions created by Eric J. Bowersox are
 * Copyright (C) 2002 Eric J. Bowersox/Silverwrist Design Studios.  All Rights Reserved.
 * 
 * Contributor(s): 
 */
package com.silverwrist.dynamo.security;

import java.util.*;
import com.silverwrist.dynamo.db.OpsBase;
import com.silverwrist.dynamo.except.*;
import com.silverwrist.dynamo.iface.*;
import com.silverwrist.dynamo.util.PropertyKey;

abstract class AuditReadOps extends OpsBase
{
  /*--------------------------------------------------------------------------------
   * Static data members
   *--------------------------------------------------------------------------------
   */

  public static final String HMKEY_NSID = "nsid";
  public static final String HMKEY_NAME = "name";
  public static final String HMKEY_DATE = "date";
  public static final String HMKEY_UID = "uid";
  public static final String HMKEY_SUBID = "subid";
  public static final String HMKEY_IP = "ip";
  public static final String HMKEY_PROPERTIES = "properties";

  public static final String HMKEY_NAMESPACE = "namespace";
  public static final String HMKEY_USER = "user";

  /*--------------------------------------------------------------------------------
   * Constructor
   *--------------------------------------------------------------------------------
   */

  protected AuditReadOps(DBConnectionPool pool)
  {
    super(pool);

  } // end constructor

  /*--------------------------------------------------------------------------------
   * Overrides from class OpsBase
   *--------------------------------------------------------------------------------
   */

  public void dispose()
  {
    super.dispose();

  } // end dispose

  /*--------------------------------------------------------------------------------
   * Abstract operations
   *--------------------------------------------------------------------------------
   */

  abstract List getAuditIDs(java.util.Date start, java.util.Date end) throws DatabaseException;

  abstract List getAuditIDs(java.util.Date start, java.util.Date end, int subid) throws DatabaseException;

  abstract List getAuditIDsBefore(java.util.Date date) throws DatabaseException;

  abstract List getAuditIDsBefore(java.util.Date date, int subid) throws DatabaseException;

  abstract List getAuditIDsAfter(java.util.Date date) throws DatabaseException;

  abstract List getAuditIDsAfter(java.util.Date date, int subid) throws DatabaseException;

  abstract List getAllAuditIDs() throws DatabaseException;

  abstract List getAllAuditIDs(int subid) throws DatabaseException;

  abstract Map getAuditRecordData(long rec_id) throws DatabaseException;

  /*--------------------------------------------------------------------------------
   * External static operations
   *--------------------------------------------------------------------------------
   */

  static AuditReadOps get(DBConnectionPool pool) throws ConfigException
  {
    return (AuditReadOps)get(pool,AuditReadOps.class.getClassLoader(),
			     AuditReadOps.class.getName() + "_","AuditReadOps");

  } // end get

} // end class AuditReadOps
