/*
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * (the "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at <http://www.mozilla.org/MPL/>.
 * 
 * Software distributed under the License is distributed on an "AS IS" basis, WITHOUT
 * WARRANTY OF ANY KIND, either express or implied. See the License for the specific
 * language governing rights and limitations under the License.
 * 
 * The Original Code is the Venice Web Communities System.
 * 
 * The Initial Developer of the Original Code is Eric J. Bowersox <erbo@silcom.com>,
 * for Silverwrist Design Studios.  Portions created by Eric J. Bowersox are
 * Copyright (C) 2002 Eric J. Bowersox/Silverwrist Design Studios.  All Rights Reserved.
 * 
 * Contributor(s): 
 */
package com.silverwrist.dynamo.servlet;

import java.io.IOException;
import java.util.*;
import com.silverwrist.util.*;
import com.silverwrist.dynamo.except.*;
import com.silverwrist.dynamo.iface.*;
import com.silverwrist.dynamo.util.*;

class Remapper implements SelfRenderable
{
  /*--------------------------------------------------------------------------------
   * Attributes
   *--------------------------------------------------------------------------------
   */

  private RemapperElement m_element;
  private HashMap m_params;

  /*--------------------------------------------------------------------------------
   * Constructor
   *--------------------------------------------------------------------------------
   */

  Remapper(RemapperElement re)
  {
    m_element = re;
    m_params = new HashMap(re.getDefaults());

  } // end 

  /*--------------------------------------------------------------------------------
   * Implementations from interface SelfRenderable
   *--------------------------------------------------------------------------------
   */

  public void render(SelfRenderControl control) throws IOException, RenderingException
  {
    URLRewriter r = (URLRewriter)(control.queryService(URLRewriter.class));
    control.redirect(r.rewriteRedirectURL(m_element.getLinkType(),
					  StringUtils.replaceAllVariables(m_element.getTemplate(),m_params)));

  } // end render

  /*--------------------------------------------------------------------------------
   * External operations
   *--------------------------------------------------------------------------------
   */

  public void setParameters(Request r)
  {
    RequestHelper rh = new RequestHelper(r);
    Iterator it = m_element.getParamNames().iterator();
    while (it.hasNext())
    { // get each parameter in turn
      String name = (String)(it.next());
      String val = rh.getParameterString(name);
      if (val!=null)
	m_params.put(name,val);

    } // end while

  } // end setParameters

} // end class Remapper
