/*
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * (the "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at <http://www.mozilla.org/MPL/>.
 * 
 * Software distributed under the License is distributed on an "AS IS" basis, WITHOUT
 * WARRANTY OF ANY KIND, either express or implied. See the License for the specific
 * language governing rights and limitations under the License.
 * 
 * The Original Code is the Venice Web Communities System.
 * 
 * The Initial Developer of the Original Code is Eric J. Bowersox <erbo@silcom.com>,
 * for Silverwrist Design Studios.  Portions created by Eric J. Bowersox are
 * Copyright (C) 2002 Eric J. Bowersox/Silverwrist Design Studios.  All Rights Reserved.
 * 
 * Contributor(s): 
 */
package com.silverwrist.dynamo.servlet;

import java.io.*;
import javax.servlet.*;
import javax.servlet.http.*;
import com.silverwrist.dynamo.except.*;
import com.silverwrist.dynamo.iface.*;
import com.silverwrist.dynamo.util.*;

class ServletBinaryRenderControl extends BaseDelegatingServiceProvider implements BinaryRenderControl
{
  /*--------------------------------------------------------------------------------
   * Attributes
   *--------------------------------------------------------------------------------
   */

  private HttpServletRequest m_req;
  private HttpServletResponse m_resp;

  /*--------------------------------------------------------------------------------
   * Constructor
   *--------------------------------------------------------------------------------
   */

  ServletBinaryRenderControl(HttpServletRequest req, HttpServletResponse resp, ServiceProvider services)
  {
    super("ServletBinaryRenderControl",services);
    m_req = req;
    m_resp = resp;

  } // end constructor

  /*--------------------------------------------------------------------------------
   * Implementations from interface RenderControl
   *--------------------------------------------------------------------------------
   */

  public void setContentType(String type)
  {
    m_resp.setContentType(type);

  } // end setContentType

  public void setContentLength(int length)
  {
    m_resp.setContentLength(length);

  } // end setContentLength

  /*--------------------------------------------------------------------------------
   * Implementations from interface BinaryRenderControl
   *--------------------------------------------------------------------------------
   */

  public OutputStream getStream() throws IOException
  {
    return m_resp.getOutputStream();

  } // end getStream

} // end class ServletBinaryRenderControl
