/*
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * (the "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at <http://www.mozilla.org/MPL/>.
 * 
 * Software distributed under the License is distributed on an "AS IS" basis, WITHOUT
 * WARRANTY OF ANY KIND, either express or implied. See the License for the specific
 * language governing rights and limitations under the License.
 * 
 * The Original Code is the Venice Web Communities System.
 * 
 * The Initial Developer of the Original Code is Eric J. Bowersox <erbo@silcom.com>,
 * for Silverwrist Design Studios.  Portions created by Eric J. Bowersox are
 * Copyright (C) 2002 Eric J. Bowersox/Silverwrist Design Studios.  All Rights Reserved.
 * 
 * Contributor(s): 
 */
package com.silverwrist.dynamo.servlet;

import java.io.*;
import javax.servlet.*;
import javax.servlet.http.*;
import org.apache.log4j.Logger;
import com.silverwrist.dynamo.except.*;
import com.silverwrist.dynamo.iface.*;
import com.silverwrist.dynamo.util.*;

class ServletTextRenderControl extends BaseDelegatingServiceProvider implements TextRenderControl
{
  /*--------------------------------------------------------------------------------
   * Static data members
   *--------------------------------------------------------------------------------
   */

  private static Logger logger = Logger.getLogger(ServletTextRenderControl.class);

  /*--------------------------------------------------------------------------------
   * Attributes
   *--------------------------------------------------------------------------------
   */

  private HttpServletRequest m_req;
  private HttpServletResponse m_resp;
  private PrintWriter m_cached_writer = null;

  /*--------------------------------------------------------------------------------
   * Constructor
   *--------------------------------------------------------------------------------
   */

  ServletTextRenderControl(HttpServletRequest req, HttpServletResponse resp, ServiceProvider services)
  {
    super("ServletTextRenderControl",services);
    m_req = req;
    m_resp = resp;

  } // end constructor

  /*--------------------------------------------------------------------------------
   * Implementations from interface RenderControl
   *--------------------------------------------------------------------------------
   */

  public void setContentType(String type)
  {
    m_resp.setContentType(type);

  } // end setContentType

  public void setContentLength(int length)
  {
    m_resp.setContentLength(length);

  } // end setContentLength

  /*--------------------------------------------------------------------------------
   * Implementations from interface TextRenderControl
   *--------------------------------------------------------------------------------
   */

  public PrintWriter getWriter() throws IOException
  {
    if (m_cached_writer==null)
      m_cached_writer = m_resp.getWriter();
    return m_cached_writer;

  } // end getWriter

  public void renderSubObject(Object obj) throws IOException, RenderingException
  {
    if (obj instanceof SelfRenderable)
    { // this object can render itself - let's do that!
      SubObjectSelfRenderControl control = new SubObjectSelfRenderControl(this);
      ((SelfRenderable)obj).render(control);
      return;

    } // end if

    QueryRenderer qrend = (QueryRenderer)(super.queryService(QueryRenderer.class));
    Renderer rend = qrend.getRendererForObject(obj);
    if (rend==null)
    { // the only thing we know about this is that we can get its string equivalent,
      // so send that out 
      PrintWriter wr = this.getWriter();
      wr.println(obj.toString());
      return;

    } // end if

    if (rend instanceof TextRenderer)
    { // render subobject here
      SubObjectTextRenderControl control = new SubObjectTextRenderControl(this);
      ((TextRenderer)rend).render(obj,control);

    } // end if
    else if (rend instanceof BinaryRenderer)
      // cannot render binary objects as a subobject to text objects!
      throw new RenderingException(ServletTextRenderControl.class,"ServletBaseMessages","binaryInsideText");
    else
    { // default to raw text
      logger.error("Unknown renderer object class: " + rend.getClass().getName());
      PrintWriter wr = this.getWriter();
      wr.println(obj.toString());

    } // end else

  } // end renderSubObject

} // end class ServletTextRenderControl
