/*
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * (the "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at <http://www.mozilla.org/MPL/>.
 * 
 * Software distributed under the License is distributed on an "AS IS" basis, WITHOUT
 * WARRANTY OF ANY KIND, either express or implied. See the License for the specific
 * language governing rights and limitations under the License.
 * 
 * The Original Code is the Venice Web Communities System.
 * 
 * The Initial Developer of the Original Code is Eric J. Bowersox <erbo@silcom.com>,
 * for Silverwrist Design Studios.  Portions created by Eric J. Bowersox are
 * Copyright (C) 2002 Eric J. Bowersox/Silverwrist Design Studios.  All Rights Reserved.
 * 
 * Contributor(s): 
 */
package com.silverwrist.dynamo.servlet;

import java.util.*;
import javax.servlet.*;
import javax.servlet.http.*;
import com.silverwrist.util.*;
import com.silverwrist.dynamo.app.RewriteRule;
import com.silverwrist.dynamo.iface.*;

class URLRewriterImpl implements URLRewriter
{
  /*--------------------------------------------------------------------------------
   * Attributes
   *--------------------------------------------------------------------------------
   */

  private HttpServletRequest m_req;
  private HttpServletResponse m_resp;
  private Map m_rewriter_map;
  private List m_type_list = null;

  /*--------------------------------------------------------------------------------
   * Constructor
   *--------------------------------------------------------------------------------
   */

  URLRewriterImpl(HttpServletRequest req, HttpServletResponse resp, Map rewriter_map)
  {
    m_req = req;
    m_resp = resp;
    m_rewriter_map = rewriter_map;

  } // end constructor

  /*--------------------------------------------------------------------------------
   * Implementations from interface URLRewriter
   *--------------------------------------------------------------------------------
   */

  public String rewriteURL(String type, String url)
  {
    RewriteRule rule = (RewriteRule)(m_rewriter_map.get(type.toUpperCase()));
    if (rule==null)
      return url;
    HashMap vars = new HashMap();
    vars.put("url",url);
    vars.put("context.path",m_req.getContextPath());
    String rc = StringUtils.replaceAllVariables(rule.getTemplate(),vars);
    if (rule.getEncode())
      return m_resp.encodeURL(rc);
    else
      return rc;

  } // end rewriteURL

  public String rewriteRedirectURL(String type, String url)
  {
    RewriteRule rule = (RewriteRule)(m_rewriter_map.get(type.toUpperCase()));
    if (rule==null)
      return url;
    HashMap vars = new HashMap();
    vars.put("url",url);
    vars.put("context.path",m_req.getContextPath());
    String rc = StringUtils.replaceAllVariables(rule.getTemplate(),vars);
    if (rule.getEncode())
      return m_resp.encodeRedirectURL(rc);
    else
      return rc;

  } // end rewriteRedirectURL

  public synchronized List getRewriteTypes()
  {
    if (m_type_list==null)
    { // create the type list
      ArrayList tmp = new ArrayList(m_rewriter_map.size());
      tmp.addAll(m_rewriter_map.keySet());
      Collections.sort(tmp);
      m_type_list = Collections.unmodifiableList(tmp);
    
    } // end if

    return m_type_list;

  } // end getRewriteTypes

} // end class URLRewriterImpl
