/*
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * (the "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at <http://www.mozilla.org/MPL/>.
 * 
 * Software distributed under the License is distributed on an "AS IS" basis, WITHOUT
 * WARRANTY OF ANY KIND, either express or implied. See the License for the specific
 * language governing rights and limitations under the License.
 * 
 * The Original Code is the Venice Web Communities System.
 * 
 * The Initial Developer of the Original Code is Eric J. Bowersox <erbo@silcom.com>,
 * for Silverwrist Design Studios.  Portions created by Eric J. Bowersox are
 * Copyright (C) 2003 Eric J. Bowersox/Silverwrist Design Studios.  All Rights Reserved.
 * 
 * Contributor(s): 
 */
package com.silverwrist.dynamo.util;

import java.io.IOException;
import com.silverwrist.dynamo.except.RenderingException;
import com.silverwrist.dynamo.servlet.ChainForward;

/**
 * A Dynamo output object that, when rendered, causes the servlet container to forward the current request to
 * a different resource identified by URI path,
 *
 * @author Eric J. Bowersox &lt;erbo@silcom.com&gt;
 * @version X
 */
public class ForwardToPath extends Forwarder
{
  /*--------------------------------------------------------------------------------
   * Constructor
   *--------------------------------------------------------------------------------
   */

  /**
   * Constructs a new <CODE>ForwardToPath</CODE> object.
   *
   * @param path The URI path to forward the request to.
   */
  public ForwardToPath(String path)
  {
    super(path);

  } // end constructor

  /*--------------------------------------------------------------------------------
   * Abstract implementations from class Forwarder
   *--------------------------------------------------------------------------------
   */

  /**
   * Actually performs the forwarding operation by forwarding to the resource path.
   *
   * @param chainer External object by which we gain access to the forwarding functionality.
   * @param param The resource path originally passed to this object by means of the constructor.
   * @exception java.io.IOException If an I/O error occurs while forwarding the request.
   * @exception com.silverwrist.dynamo.except.RenderingException If we are unable to forward the request.
   */
  protected void doForward(ChainForward chainer, String param) throws IOException, RenderingException
  {
    chainer.chainToPath(param);

  } // end doForward

} // end class ForwardToPath
