/*
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * (the "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at <http://www.mozilla.org/MPL/>.
 * 
 * Software distributed under the License is distributed on an "AS IS" basis, WITHOUT
 * WARRANTY OF ANY KIND, either express or implied. See the License for the specific
 * language governing rights and limitations under the License.
 * 
 * The Original Code is the Venice Web Communities System.
 * 
 * The Initial Developer of the Original Code is Eric J. Bowersox <erbo@silcom.com>,
 * for Silverwrist Design Studios.  Portions created by Eric J. Bowersox are
 * Copyright (C) 2003 Eric J. Bowersox/Silverwrist Design Studios.  All Rights Reserved.
 * 
 * Contributor(s): 
 */
package com.silverwrist.dynamo.util;

import java.io.*;
import com.silverwrist.dynamo.iface.*;

public class PrefixResourceProvider implements ResourceProvider
{
  /*--------------------------------------------------------------------------------
   * Attributes
   *--------------------------------------------------------------------------------
   */

  private ResourceProvider m_inner;
  private String m_prefix;

  /*--------------------------------------------------------------------------------
   * Constructor
   *--------------------------------------------------------------------------------
   */

  public PrefixResourceProvider(ResourceProvider inner, String prefix)
  {
    m_inner = inner;
    m_prefix = prefix;
    while ((m_prefix.length()>0) && m_prefix.endsWith("/"))
      m_prefix = m_prefix.substring(0,m_prefix.length()-1);

  } // end constructor

  /*--------------------------------------------------------------------------------
   * Implementations from interface ResourceProvider
   *--------------------------------------------------------------------------------
   */

  public InputStream getResource(String resource_path) throws IOException
  {
    return m_inner.getResource(m_prefix + resource_path);

  } // end getResource

  public long getResourceModTime(String resource_path)
  {
    return m_inner.getResourceModTime(m_prefix + resource_path);

  } // end getResourceModTime

} // end class PrefixResourceProvider
