/*
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * (the "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at <http://www.mozilla.org/MPL/>.
 * 
 * Software distributed under the License is distributed on an "AS IS" basis, WITHOUT
 * WARRANTY OF ANY KIND, either express or implied. See the License for the specific
 * language governing rights and limitations under the License.
 * 
 * The Original Code is the Venice Web Communities System.
 * 
 * The Initial Developer of the Original Code is Eric J. Bowersox <erbo@silcom.com>,
 * for Silverwrist Design Studios.  Portions created by Eric J. Bowersox are
 * Copyright (C) 2003 Eric J. Bowersox/Silverwrist Design Studios.  All Rights Reserved.
 * 
 * Contributor(s): 
 */
package com.silverwrist.venice.community;

import java.util.List;
import com.silverwrist.dynamo.except.DatabaseException;
import com.silverwrist.dynamo.except.DynamoSecurityException;
import com.silverwrist.dynamo.iface.DynamoUser;
import com.silverwrist.venice.CommunitySearchField;
import com.silverwrist.venice.SearchMode;
import com.silverwrist.venice.iface.VeniceCategory;
import com.silverwrist.venice.iface.VeniceCommunity;

public interface CommunityService
{
  public List getMemberCommunities(DynamoUser caller, DynamoUser user)
      throws DatabaseException, DynamoSecurityException;

  public VeniceCommunity getCommunity(int cid) throws DatabaseException;

  public VeniceCommunity getCommunity(String alias) throws DatabaseException;

  public List searchForCommunities(DynamoUser caller, CommunitySearchField field, SearchMode mode, String term,
				   int offset, int count) throws DatabaseException;

  public int getSearchCommunityCount(DynamoUser caller, CommunitySearchField field, SearchMode mode, String term)
      throws DatabaseException;

  public List getCommunitiesInCategory(DynamoUser caller, int catid, int offset, int count) throws DatabaseException;

  public List getCommunitiesInCategory(DynamoUser caller, VeniceCategory cat, int offset, int count)
      throws DatabaseException;

  public int getNumCommunitiesInCategory(DynamoUser caller, int catid) throws DatabaseException;

  public int getNumCommunitiesInCategory(DynamoUser caller, VeniceCategory cat) throws DatabaseException;

  public List getAvailableServices();

  public CommunityServiceDescriptor getServiceForID(int id);

  public CommunityServiceDescriptor getServiceForName(String namespace, String name);

} // end interface CommunityService
