/*
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * (the "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at <http://www.mozilla.org/MPL/>.
 * 
 * Software distributed under the License is distributed on an "AS IS" basis, WITHOUT
 * WARRANTY OF ANY KIND, either express or implied. See the License for the specific
 * language governing rights and limitations under the License.
 * 
 * The Original Code is the Venice Web Communities System.
 * 
 * The Initial Developer of the Original Code is Eric J. Bowersox <erbo@silcom.com>,
 * for Silverwrist Design Studios.  Portions created by Eric J. Bowersox are
 * Copyright (C) 2003 Eric J. Bowersox/Silverwrist Design Studios.  All Rights Reserved.
 * 
 * Contributor(s): 
 */
package com.silverwrist.venice.obj;

import com.silverwrist.dynamo.except.*;
import com.silverwrist.dynamo.iface.*;
import com.silverwrist.dynamo.obj.*;
import com.silverwrist.venice.iface.*;

public class DynamicImplCommunityServiceController extends DynamicObjectImpl
{
  /*--------------------------------------------------------------------------------
   * Static data members
   *--------------------------------------------------------------------------------
   */

  private static DynamicClass s_baseclass = null;

  /*--------------------------------------------------------------------------------
   * Attributes
   *--------------------------------------------------------------------------------
   */

  private CommunityServiceController m_impl;

  /*--------------------------------------------------------------------------------
   * Constructors
   *--------------------------------------------------------------------------------
   */

  public DynamicImplCommunityServiceController(CommunityServiceController impl)
  {
    super(getBaseDClass());
    m_impl = impl;

  } // end constructor

  public DynamicImplCommunityServiceController(CommunityServiceController impl, DynamicClass dclass)
  {
    super(dclass);
    m_impl = impl;

  } // end constructor

  /*--------------------------------------------------------------------------------
   * Overrides from class DynamicObjectImpl
   *--------------------------------------------------------------------------------
   */

  public Object get(String property_name) throws DynamicObjectException
  {
    if (property_name.equals("description"))
      return m_impl.getDescription();
    if (property_name.equals("accessObject"))
      return m_impl.getAccessObject();
    return super.get(property_name);

  } // end get

  public Object call(String method_name, Object[] parameters) throws DynamicObjectException
  {
    // N.B.: "shutdown" should NOT be a dynamic call

    if (method_name.equals("getDescription"))
    { // call getDescription
      verifyParameterLength(method_name,parameters,0);
      return m_impl.getDescription();

    } // end if

    // N.B.: "addServiceToCommunity" should NOT be a dynamic call
    // N.B.: "removeServiceFromCommunity" should NOT be a dynamic call

    if (method_name.equals("getAccessObject"))
    { // call getAccessObject
      verifyParameterLength(method_name,parameters,0);
      return m_impl.getAccessObject();

    } // end if

    return super.call(method_name,parameters);

  } // end call

  /*--------------------------------------------------------------------------------
   * External static operations
   *--------------------------------------------------------------------------------
   */

  public static synchronized DynamicClass getBaseDClass()
  {
    if (s_baseclass==null)
      s_baseclass = new DynamicClassCommunityServiceController();
    return s_baseclass;

  } // end getBaseDClass

} // end class DynamicImplCommunityServiceController
