/*
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * (the "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at <http://www.mozilla.org/MPL/>.
 * 
 * Software distributed under the License is distributed on an "AS IS" basis, WITHOUT
 * WARRANTY OF ANY KIND, either express or implied. See the License for the specific
 * language governing rights and limitations under the License.
 * 
 * The Original Code is the Venice Web Communities System.
 * 
 * The Initial Developer of the Original Code is Eric J. Bowersox <erbo@silcom.com>,
 * for Silverwrist Design Studios.  Portions created by Eric J. Bowersox are
 * Copyright (C) 2002 Eric J. Bowersox/Silverwrist Design Studios.  All Rights Reserved.
 * 
 * Contributor(s): 
 */
package com.silverwrist.venice.servlet;

import java.io.*;
import java.util.*;
import com.silverwrist.util.*;
import com.silverwrist.dynamo.except.*;
import com.silverwrist.dynamo.iface.*;

class BinaryPageData extends PageData
{
  /*--------------------------------------------------------------------------------
   * Attributes
   *--------------------------------------------------------------------------------
   */

  private String m_type;
  private int m_length;

  /*--------------------------------------------------------------------------------
   * Constructor
   *--------------------------------------------------------------------------------
   */

  BinaryPageData(File file, String type) throws IOException
  {
    super(file);
    m_type = type;
    m_length = (int)(file.length());

  } // end constructor

  /*--------------------------------------------------------------------------------
   * Abstract implementations from class PageData
   *--------------------------------------------------------------------------------
   */

  public void render(SelfRenderControl control) throws IOException, RenderingException
  {
    BinaryRenderControl c = control.getBinaryRender();
    c.setContentType(m_type);
    c.setContentLength(m_length);
    InputStream in = null;
    OutputStream out = c.getStream();
    try
    { // copy the data out!
      in = new FileInputStream(m_file);
      IOUtils.copy(in,out);
      out.flush();

    } // end try
    finally
    { // close the file stream when we're done
      IOUtils.shutdown(in);

    } // end finally;
    
  } // end render

} // end class BinaryPageData
