/*
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * (the "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at <http://www.mozilla.org/MPL/>.
 * 
 * Software distributed under the License is distributed on an "AS IS" basis, WITHOUT
 * WARRANTY OF ANY KIND, either express or implied. See the License for the specific
 * language governing rights and limitations under the License.
 * 
 * The Original Code is the Venice Web Communities System.
 * 
 * The Initial Developer of the Original Code is Eric J. Bowersox <erbo@silcom.com>,
 * for Silverwrist Design Studios.  Portions created by Eric J. Bowersox are
 * Copyright (C) 2003 Eric J. Bowersox/Silverwrist Design Studios.  All Rights Reserved.
 * 
 * Contributor(s): 
 */
package com.silverwrist.venice.servlet;

import com.silverwrist.dynamo.HttpStatusCode;
import com.silverwrist.dynamo.Namespaces;
import com.silverwrist.dynamo.except.*;
import com.silverwrist.dynamo.iface.*;
import com.silverwrist.dynamo.servlet.ServletBase;
import com.silverwrist.dynamo.util.*;
import com.silverwrist.venice.VeniceNamespaces;
import com.silverwrist.venice.community.CommunityService;
import com.silverwrist.venice.iface.*;

public class CommunityServlet extends ServletBase
{
  /*--------------------------------------------------------------------------------
   * Abstract implementations from class ServletBase
   *--------------------------------------------------------------------------------
   */

  protected Object process(Request r, Application app) throws Exception
  {
    // Look up the community.
    ObjectProvider op = (ObjectProvider)(r.queryService(ObjectProvider.class));
    CommunityService csvc = (CommunityService)(op.getObject(Namespaces.DYNAMO_OBJECT_NAMESPACE,"communities"));
    VeniceCommunity comm = null;
    try
    { // get the community by its alias
      comm = csvc.getCommunity(r.getExtraPath().substring(1));

    } // end try
    catch (DatabaseException e)
    { // handle "not-found" errors in a special way
      if (e.getMessageID().equals("cid.notFound"))
	return new HttpErrorMessage(HttpStatusCode.E_NOTFOUND);
      throw e;

    } // end catch

    // Execute the script that produces the value.
    r.setObject(VeniceNamespaces.COMMUNITY_NAMESPACE,"current",comm);
    ScriptExecute exec = (ScriptExecute)(r.queryService(ScriptExecute.class));
    return exec.executeScript(r,"/util/comm/homepage.js");
    
  } // end process

} // end class CommunityServlet
