/*
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * (the "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at <http://www.mozilla.org/MPL/>.
 * 
 * Software distributed under the License is distributed on an "AS IS" basis, WITHOUT
 * WARRANTY OF ANY KIND, either express or implied. See the License for the specific
 * language governing rights and limitations under the License.
 * 
 * The Original Code is the Venice Web Communities System.
 * 
 * The Initial Developer of the Original Code is Eric J. Bowersox <erbo@silcom.com>,
 * for Silverwrist Design Studios.  Portions created by Eric J. Bowersox are
 * Copyright (C) 2002 Eric J. Bowersox/Silverwrist Design Studios.  All Rights Reserved.
 * 
 * Contributor(s): 
 */
package com.silverwrist.venice.servlet;

import java.io.*;
import java.util.*;
import com.silverwrist.util.*;
import com.silverwrist.dynamo.except.*;
import com.silverwrist.dynamo.iface.*;

abstract class PageData implements SelfRenderable
{
  /*--------------------------------------------------------------------------------
   * Attributes
   *--------------------------------------------------------------------------------
   */

  protected File m_file;     // underlying File object
  private long m_lastmod;    // initial "last modified" time

  /*--------------------------------------------------------------------------------
   * Constructor
   *--------------------------------------------------------------------------------
   */

  protected PageData(File file) throws IOException
  {
    m_file = file;
    m_lastmod = m_file.lastModified();

  } // end constructor

  /*--------------------------------------------------------------------------------
   * Abstract operations from interface SelfRenderable
   *--------------------------------------------------------------------------------
   */

  public abstract void render(SelfRenderControl control) throws IOException, RenderingException;

  /*--------------------------------------------------------------------------------
   * External operations
   *--------------------------------------------------------------------------------
   */

  boolean isModified()
  {
    long tmp = m_file.lastModified();
    if (tmp==0)
      return true;
    else
      return (tmp>m_lastmod);

  } // end isModified

} // end class PageData
